@@ -2,9 +2,7 @@
 use strict;
 use warnings;
 use utf8;
-use open qw/:std :encoding(utf-8)/;
 
-use JSON 2;
 use Storable 2.38 qw/nfreeze/;
 use MIME::Base64;
 use Path::Tiny;
@@ -18,13 +16,13 @@ my $file = shift @ARGV or die "Usage: $0 target.toml";
 
 my $toml      = path($file)->slurp_utf8;
 my $toml_data = TOML::Parser->new->parse($toml);
-printf <<'...', encode_base64(nfreeze($toml_data)), $file, $toml;
+printf <<'...', encode_base64(nfreeze($toml_data)), $file, $toml =~ s/\n\z//mr;
 use strict;
 use warnings;
 use utf8;
 
 use Test::More tests => 2;
-use t::Util;
+use Test::Deep;
 use Storable 2.38 qw/thaw/;
 use MIME::Base64;
 
@@ -40,7 +38,7 @@ for my $strict_mode (0, 1) {
     my $parser = TOML::Parser->new(strict_mode => $strict_mode);
     my $data   = $parser->parse($toml);
     note explain { data => $data, expected => $expected } if $ENV{AUTHOR_TESTING};
-    cmp_fuzzy_deeply $data => $expected, "%s: strict_mode: $strict_mode";
+    cmp_deeply $data => $expected, "%s: strict_mode: $strict_mode";
 }
 
 __DATA__
